/***************************************************************************
                          rchoosemach.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

/****************************************************************************
** rchoosemach.h 1998/09/03 A. Mustun RibbonSoft 
**
** Copyright (C) 1998 RibbonSoft.  All rights reserved.
**
*****************************************************************************/

#ifndef RCHOOSEMACH_H
#define RCHOOSEMACH_H

#include <qdialog.h>

#define DEF_CHOOSEMACH_WIDTH  360
#define DEF_CHOOSEMACH_HEIGHT 120

class QLabel;
class RComboBox;

class RChooseMach : public QDialog
{
  Q_OBJECT
public:
  RChooseMach(QWidget* _parent=0, 
              const char* _name=0);
  ~RChooseMach();

  const char* getMachine();

private slots:
  void addNew();
  void addNewDerivation();
  void deleteMach();
    
private:
  QPushButton* bOk;
  QPushButton* bCancel;
  QPushButton* bHelp;

  QLabel*      lText;
  RComboBox*   mbMachine;

  QPushButton* bNew;
  QPushButton* bNewDerivation;
  QPushButton* bDel;
  
};


#endif

// EOF


